@@ -135,9 +135,27 @@ sub fixup_glyph {
 }
 
 sub draw {
-  my $self = shift;
-  $self->fixup_glyph();
-  $self->SUPER::draw(@_);
+    my $self = shift;
+    $self->SUPER::draw(@_);
+
+    return unless $self->thin_utr;
+    my $gd       = shift;
+    my ($dx,$dy) = @_;
+    my $bgcolor = $self->bgcolor;
+
+    my @parts = $self->parts;
+    for (my $i = 0; $i < @parts; $i++) {
+	if ($i >= 1 && ($parts[$i-1]->is_utr != $parts[$i]->is_utr)) {
+	    next unless $parts[$i-1]->end+1 == $parts[$i]->start;
+	    my ($x1,$y1,$x2,$y2) = $parts[$i]->bounds($dx,$dy+$self->top+$self->pad_top);
+	    my $height           = $parts[$i-1]->is_utr ? 
+		                       $parts[$i-1]->height 
+				     : $parts[$i]->height;
+	    my $center           = ($y1+$y2)/2;
+	    $gd->line($x1,$center-$height/2,$x1,$center+$height/2,$bgcolor); # erase
+	}
+    }
+
 }
 
 sub boxes {
